import { PluginCreator } from 'tailwindcss/types/config';

const creator: PluginCreator = ({ addComponents, theme }) =>
	addComponents({
		'.menu': {
			'&-container': {
				position: 'relative',
			},
			'&-item': {
				display: 'flex',
				alignItems: 'center',
				justifyContent: 'space-between',
				fontSize: '1rem',
				cursor: 'pointer',
				whiteSpace: 'nowrap',
				position: 'relative',
				margin: '0.25rem',
				padding: '.25rem .5rem',
				borderRadius: theme('borderRadius.md'),
			},
		},
		'.page': {},
		'.page-top': {
			display: 'flex',
			marginBottom: '0.25rem',
			height: '2.75rem',
			borderBottom: `1px solid ${theme('colors.navigation.top.border')}`,
			'&-logo': {
				marginRight: '.25rem',
				display: 'flex',
				alignSelf: 'center',
				fontSize: '1.25rem',
				padding: '0 0.5rem',
				color: theme('colors.navigation.logo.color'),
			},
			'&-content': {
				display: 'flex',
				alignItems: 'center',
				width: '100%',
				backgroundColor: theme('colors.navigation.top.background'),
				'.menu-item': {
					color: theme('colors.navigation.top.color'),
					'&:hover, &--active': {
						backgroundColor: theme('colors.navigation.top.active.background'),
						color: theme('colors.navigation.top.active.color'),
					},
					'&-icon': {
						marginRight: '0.25rem',
						fontSize: '1rem',
						'&-only': {
							marginLeft: '-.25rem',
							marginRight: '-.25rem',
						},
					},
				},
			},
		},
		'.page-main': {
			minHeight: '90vh',
			'.side': {
				color: theme('colors.navigation.side.color'),
				backgroundColor: theme('colors.navigation.side.background'),
				border: `1px solid ${theme('colors.navigation.side.border')}`,
				borderRadius: theme('borderRadius.sm'),
				position: 'relative',
				paddingTop: '2.5rem',
				margin: '.125rem',
				display: 'flex',
				flexDirection: 'column',
				flexShrink: '0',
				'&-toggler': {
					position: 'absolute',
					top: '0.5rem',
					right: '0.5rem',
					cursor: 'pointer',
					fontSize: '1rem',
					color: theme('colors.navigation.side.toggler.color'),
				},
				'.menu-item': {
					whiteSpace: 'nowrap',
					justifyContent: 'start',
					padding: '.5rem',
					'&:hover, &--active': {
						backgroundColor: theme('colors.navigation.side.active.background'),
					},
					'&-tooltip': {
						position: 'absolute',
						left: '3rem',
						padding: '0.25rem 1rem',
						backgroundColor: theme('colors.black'),
						borderRadius: theme('borderRadius.md'),
						display: 'none',
					},
					'&:hover .menu-item-tooltip': {
						display: 'block',
					},
				},
				'&--collapsed': {
					'.menu-item': {
						'&-tooltip': {
							color: theme('colors.white'),
						},
					},
				},
				'&--expand': {
					width: '12rem',
					whiteSpace: 'nowrap',
					'.menu-item-icon': {
						marginRight: '0.5rem',
					},
				},
			},
			'.content': {
				margin: '0.25rem',
				width: 'calc(100% - .5rem)',
			},
		},
		// mobile
		[`@media (max-width: ${theme('screens.md-m.max')})`]: {
			'.page-top': {
				height: 'auto',
				'&-toggler': {
					fontSize: '1.5rem',
					color: theme('colors.white'),
					alignSelf: 'center',
					marginRight: '1rem',
				},
				'&-logo': {
					alignSelf: 'start',
				},
				'&-control': {
					display: 'flex',
					justifyContent: 'space-between',
					alignSelf: 'normal',
				},
				'&-content': {
					height: 'auto',
					flexDirection: 'column',
					'.menu-container': {
						width: '100%',
					},
					'.menu-item': {
						justifyContent: 'normal',
						'&-icon-only': {
							marginLeft: '0',
							marginRight: '0',
						},
					},
				},
			},
			'.side.side--collapsed': {
				'& .menu-item': {
					padding: '.125rem',
					margin: '.125rem',
				},
			},
		},
	});

export default creator;
